@@ -31,7 +31,7 @@ pub struct UpdateEventInput {
     pub start_ts: Option<i64>,
     pub duration: Option<i64>,
     pub busy: Option<bool>,
-    pub reminder: Option<CalendarEventReminder>,
+    pub reminders: Option<Vec<CalendarEventReminder>>,
     pub rrule_options: Option<RRuleOptions>,
     pub service_id: Option<ID>,
     pub exdates: Option<Vec<i64>>,
@@ -103,7 +103,7 @@ impl CalendarEventClient {
             duration: input.duration,
             exdates: input.exdates,
             recurrence: input.rrule_options,
-            reminder: input.reminder,
+            reminders: input.reminders,
             service_id: input.service_id,
             start_ts: input.start_ts,
             metadata: input.metadata,
